get_discrepancy_rank: Extractor for pairwise discrepancy rankings

View source: R/extractors.R

get_discrepancy_rankR Documentation

Extractor for pairwise discrepancy rankings

Description

Provide the matrix storing the ranks of discrepancies using Inversion-Best Matching approach between all couples among the K (K>2) samples under study.

Usage

get_discrepancy_rank(x)

Arguments

x

An object of class IBM_test.

Value

A matrix of ranks, from the closest couple (rank 1) in terms of discrepancy measure to the most different one.

Author(s)

Xavier Milhaud xavier.milhaud.research@gmail.com


admix documentation built on Jan. 8, 2026, 5:07 p.m.