| get_known_component | R Documentation |
Get the known component of the admixture model considered for estimation, test, or clustering.
get_known_component(x)
x |
An object of class |
This is a generic extractor, providing with the same information whatever the object class.
A list providing information on the known component (distribution, parameters).
Xavier Milhaud xavier.milhaud.research@gmail.com
## Simulate a two-component Gaussian mixture:
mixt1 <- twoComp_mixt(n = 380, weight = 0.7,
comp.dist = list("norm", "norm"),
comp.param = list(list("mean" = -2, "sd" = 0.5),
list("mean" = 0, "sd" = 1)))
data1 <- get_mixture_data(mixt1)
admixMod1 <- admix_model(knownComp_dist = mixt1$comp.dist[[2]],
knownComp_param = mixt1$comp.param[[2]])
## Estimate the unknown quantities:
x <- admix_estim(samples = list(data1), admixMod = list(admixMod1), est_method = "BVdk")
## Extract the information about the known component:
get_known_component(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.