get_statistic_components: Extractor for components involved in test statistic

View source: R/extractors.R

get_statistic_componentsR Documentation

Extractor for components involved in test statistic

Description

Provide the terms (or discrepancies) that compose the test statistic for the k-sample test.

Usage

get_statistic_components(x)

Arguments

x

An object of class IBM_test.

Value

The components finally included in the test statistic, i.e. the discrepancies of the couples that were aggregated in the built sequence of statistics.

Author(s)

Xavier Milhaud xavier.milhaud.research@gmail.com


admix documentation built on Jan. 8, 2026, 5:07 p.m.