| get_discrepancy_rank | R Documentation |
Provide the matrix storing the ranks of discrepancies using Inversion-Best Matching approach between all couples among the K (K>2) samples under study.
get_discrepancy_rank(x)
x |
An object of class |
A matrix of ranks, from the closest couple (rank 1) in terms of discrepancy measure to the most different one.
Xavier Milhaud xavier.milhaud.research@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.