Learn R Programming

admix (version 2.4.3)

get_discrepancy_rank: Extractor for object of class 'IBM_test'

Description

Provide the matrix storing the ranks of discrepancies using Inversion-Best Matching approach between all couples among the K samples under study.

Usage

get_discrepancy_rank(x)

Arguments

x

An object of class 'IBM_test'.