| get_statistic_components | R Documentation |
Provide the terms (or discrepancies) that compose the test statistic for the k-sample test.
get_statistic_components(x)
x |
An object of class |
The components finally included in the test statistic, i.e. the discrepancies of the couples that were aggregated in the built sequence of statistics.
Xavier Milhaud xavier.milhaud.research@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.