| plot.twoComp_mixt | R Documentation |
Plots the empirical densities of the samples provided, with optional arguments to improve the visualization.
## S3 method for class 'twoComp_mixt'
plot(x, add_plot = FALSE, offset = 0, bar_width = 0.2, ...)
x |
Object of class |
add_plot |
(default to FALSE) Option to plot another mixture distribution on the same graph. |
offset |
Numeric. Position of the bars relative to the labels on the x-axis. |
bar_width |
Width of bars to be plotted. |
... |
further classical arguments and graphical parameters for methods plot and hist. |
A plot with the densities of the samples provided as inputs.
Xavier Milhaud xavier.milhaud.research@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.